@@ -43,7 +43,7 @@ sub _monikerize {
 sub run_tests {
     my $self = shift;
 
-    plan tests => 73;
+    plan tests => 76;
 
     $self->create();
 
@@ -124,6 +124,11 @@ sub run_tests {
     isa_ok( $rsobj23, "DBIx::Class::ResultSet" );
     isa_ok( $rsobj24, "DBIx::Class::ResultSet" );
 
+    my @columns_lt2 = $class2->columns;
+    is($columns_lt2[0], 'id', "Column Ordering 0");
+    is($columns_lt2[1], 'dat', "Column Ordering 1");
+    is($columns_lt2[2], 'dat2', "Column Ordering 2");
+
     my %uniq1 = $class1->unique_constraints;
     my $uniq1_test = 0;
     foreach my $ucname (keys %uniq1) {
@@ -230,7 +235,7 @@ sub run_tests {
     ok($new_obj1) or diag "Cannot find newly inserted PK::Auto record";
     is($new_obj1->id, $saved_id);
 
-    my ($obj2) = $rsobj2->find( dat => 'bbb' );
+    my ($obj2) = $rsobj2->search({ dat => 'bbb' })->first;
     is( $obj2->id, 2 );
 
     SKIP: {
@@ -316,7 +321,7 @@ sub run_tests {
         isa_ok( $rs_rel4->first, $class4);
 
         # find on multi-col pk
-        my $obj5 = $rsobj5->find( id1 => 1, id2 => 1 );
+        my $obj5 = $rsobj5->find({id1 => 1, id2 => 1});
         is( $obj5->id2, 1 );
 
         # mulit-col fk def
